"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteBookmark = exports.createBookmark = exports.listBookmarks = exports.SortOrder = exports.StateFilter = exports.ScheduleStatus = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixEventsScheduleV1ScheduleItem = __importStar(require("./events-schedule-v1-schedule-item-schedule-bookmarks.http.js"));
var ScheduleStatus;
(function (ScheduleStatus) {
    /** Item is scheduled for a future date. */
    ScheduleStatus["SCHEDULED"] = "SCHEDULED";
    /** Item is canceled. */
    ScheduleStatus["CANCELED"] = "CANCELED";
})(ScheduleStatus || (exports.ScheduleStatus = ScheduleStatus = {}));
var StateFilter;
(function (StateFilter) {
    /** Schedule item is published. */
    StateFilter["PUBLISHED"] = "PUBLISHED";
    /** Schedule item is in draft. */
    StateFilter["DRAFT"] = "DRAFT";
    /** Schedule item is visible to the event's guests. */
    StateFilter["VISIBLE"] = "VISIBLE";
    /** Schedule item is hidden to the event's guests. */
    StateFilter["HIDDEN"] = "HIDDEN";
})(StateFilter || (exports.StateFilter = StateFilter = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
/**
 * Retrieves a list of bookmarked schedule items for a current member.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @permissionId WIX_EVENTS.READ_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.ListBookmarks
 */
async function listBookmarks(eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ eventId: eventId });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.listBookmarks(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { eventId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listBookmarks = listBookmarks;
/**
 * Bookmarks a schedule item for a current member.
 * @param itemId - Schedule item ID.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @requiredField itemId
 * @permissionId WIX_EVENTS.MANAGE_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.CreateBookmark
 */
async function createBookmark(itemId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        itemId: itemId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.createBookmark(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { itemId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['itemId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createBookmark = createBookmark;
/**
 * Removes a schedule item bookmark for a current member.
 * @param itemId - Schedule item ID.
 * @param eventId - Event ID to which the schedule item belongs.
 * @public
 * @requiredField eventId
 * @requiredField itemId
 * @permissionId WIX_EVENTS.MANAGE_AGENDA_BOOKMARKS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity MEMBER
 * @fqn wix.events.schedule.BookmarkManagement.DeleteBookmark
 */
async function deleteBookmark(itemId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        itemId: itemId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsScheduleV1ScheduleItem.deleteBookmark(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { itemId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['itemId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteBookmark = deleteBookmark;
//# sourceMappingURL=events-schedule-v1-schedule-item-schedule-bookmarks.universal.js.map