"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteBookmark = exports.createBookmark = exports.listBookmarks = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixEventsScheduleBookmarkManagementUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/wix-events-agenda',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        _: [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        '*.pub.wix-code.com': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor-flow.wixapps.net': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/events/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'api._base_domain_': [
            {
                srcPath: '/events/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_events_schedule-bookmarks';
/** Retrieves a list of bookmarked schedule items for a current member. */
function listBookmarks(payload) {
    function __listBookmarks({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'GET',
            methodFqn: 'wix.events.schedule.BookmarkManagement.ListBookmarks',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/bookmarks',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'items.createdDate' },
                        { path: 'items.updatedDate' },
                        { path: 'items.timeSlot.start' },
                        { path: 'items.timeSlot.end' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listBookmarks;
}
exports.listBookmarks = listBookmarks;
/** Bookmarks a schedule item for a current member. */
function createBookmark(payload) {
    function __createBookmark({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'POST',
            methodFqn: 'wix.events.schedule.BookmarkManagement.CreateBookmark',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/{itemId}/bookmark',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __createBookmark;
}
exports.createBookmark = createBookmark;
/** Removes a schedule item bookmark for a current member. */
function deleteBookmark(payload) {
    function __deleteBookmark({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'DELETE',
            methodFqn: 'wix.events.schedule.BookmarkManagement.DeleteBookmark',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/{itemId}/bookmark',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteBookmark;
}
exports.deleteBookmark = deleteBookmark;
//# sourceMappingURL=events-schedule-v1-schedule-item-schedule-bookmarks.http.js.map