import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixEventsScheduleBookmarkManagementUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/wix-events-agenda',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        _: [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        '*.pub.wix-code.com': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor-flow.wixapps.net': [
            {
                srcPath: '/_api/wix-events-schedule/v1/schedule',
                destPath: '/v1/schedule',
            },
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/events/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'api._base_domain_': [
            {
                srcPath: '/events/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/_api/wix-events-web/v1/schedule',
                destPath: '/v1/schedule',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_events_schedule-bookmarks';
/** Retrieves a list of bookmarked schedule items for a current member. */
export function listBookmarks(payload) {
    function __listBookmarks({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'GET',
            methodFqn: 'wix.events.schedule.BookmarkManagement.ListBookmarks',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/bookmarks',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'items.createdDate' },
                        { path: 'items.updatedDate' },
                        { path: 'items.timeSlot.start' },
                        { path: 'items.timeSlot.end' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listBookmarks;
}
/** Bookmarks a schedule item for a current member. */
export function createBookmark(payload) {
    function __createBookmark({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'POST',
            methodFqn: 'wix.events.schedule.BookmarkManagement.CreateBookmark',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/{itemId}/bookmark',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __createBookmark;
}
/** Removes a schedule item bookmark for a current member. */
export function deleteBookmark(payload) {
    function __deleteBookmark({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.schedule.v1.schedule_item',
            method: 'DELETE',
            methodFqn: 'wix.events.schedule.BookmarkManagement.DeleteBookmark',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsScheduleBookmarkManagementUrl({
                protoPath: '/v1/schedule/{itemId}/bookmark',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteBookmark;
}
//# sourceMappingURL=events-schedule-v1-schedule-item-schedule-bookmarks.http.js.map